#
# spec file for package solaar
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define pythons python3
%define skip_python2 1
%define skip_python36 1
Name:           solaar
Version:        1.1.5
Release:        bp156.2.2
Summary:        Linux devices manager for the Logitech Unifying Receiver
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://pwr-solaar.github.io/Solaar
Source0:        Solaar-%{version}.tar.gz
#PATCH-FIX-OPENSUSE solaar-fix-desktop-categories.patch malcolmlewis@opensuse.org -- Fix desktop categories as per openSUSE desktop file specification.
Patch0:         solaar-fix-desktop-categories.patch
#
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module evdev}
BuildRequires:  %{python_module gobject-Gdk}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module python-xlib}
BuildRequires:  %{python_module pyudev}
BuildRequires:  %{python_module setuptools}
#
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  typelib-1_0-Gtk-3_0
BuildRequires:  update-desktop-files
Requires:       python3-PyYAML
%if 0%{?suse_version} <= 1500
Requires:       python3-dataclasses
%endif
Requires:       python3-evdev
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-psutil
Requires:       python3-python-xlib
Requires:       python3-pyudev
#
Requires:       solaar-udev >= %{version}
Requires:       typelib-1_0-Gtk-3_0
#
Obsoletes:      solaar-cli < %{version}
Provides:       solaar-cli = %{version}
#
BuildArch:      noarch

%description
Solaar will detect all devices paired with your Unifying Receiver, and
at the very least display some basic information about them.

For some devices, extra settings (usually not available through the
standard Linux system configuration) are supported. For a full list of
supported devices and their features, see docs/devices.md.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other

%description    doc
Solaar will detect all devices paired with your Unifying Receiver, and
at the very least display some basic information about them.

For some devices, extra settings (usually not available through the
standard Linux system configuration) are supported. For a full list of
supported devices and their features, see docs/devices.md.

%package        udev
Summary:        Udev rules for accessing Logitech Unifying Receiver
Group:          Hardware/Other
Requires:       udev
Conflicts:      solaar-cli < %{version}

%description    udev
Rules that users are able to access Logitech Unifying Receiver.

%prep
%autosetup -p1 -n Solaar-%{version}

# Fix desktop file installation
sed -i '/yield autostart_path/d' setup.py

%build
sed -i 's#%{_bindir}/env python##' lib/solaar/gtk.py lib/solaar/tasks.py
%python_build

%install
%python_install
%fdupes %{buildroot}%{python3_sitelib}
%fdupes -s %{buildroot}%{_datadir}
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}.desktop

install -d 0755 %{buildroot}%{_udevrulesdir}
install -m 0644 rules.d/42-logitech-unify-permissions.rules %{buildroot}%{_udevrulesdir}/42-logitech-unify-permissions.rules

ln -s solaar %{buildroot}%{_bindir}/solaar-cli

%posttrans udev
# This is needed to apply permissions to existing devices when the package is
# installed.
%{_bindir}/udevadm trigger --subsystem-match=hidraw --action=add

%files
%doc ChangeLog.md COPYRIGHT README.md Release_Notes.md
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/solaar.svg
%{_datadir}/metainfo/io.github.pwr_solaar.solaar.metainfo.xml
%{python_sitelib}/hidapi
%{python_sitelib}/logitech_receiver
%{python_sitelib}/keysyms
%{python_sitelib}/solaar
%{python_sitelib}/solaar-*

%files udev
%{_udevrulesdir}/42-logitech-unify-permissions.rules

%files doc
%doc docs/*

%changelog
* Thu Sep 15 2022 asn@cryptomilk.org
- Update to version 1.1.5:
  * release 1.1.5
  * docs: add several device descriptions
  * device: add G213 Prodigy Gaming Keyboard
  * po: Update Croatian translation (#1759)
  * po: update zh_CN translation
  * po: update Polish translation
  * chore: clean a redundant space in a UI label
  * release 1.1.5rc1
  * po: Turkish translate completed (#1752)
  * docs: move old device descriptions to new locations and fix up
  * settings: increase minimum stopped time betweeen mouse movements
  * rules: fix bug with non-recognized empty mouse movement
  * docs: fix typos in Solaar options documentation
  * ui: allow config panel to scroll
  * doc: descriptions for K360 4004 and MX Master 4071
  * doc: descriptions for Lightspeed Receiver C541 and G915 WIRELESS RGB Mechanical Gaming Keyboard 407E
  * ui: change security tooltip for unencrypted wireless connections
  * po: Norwegian Bokmal
  * doc: add known issue for key presses and changing hosts
  * docs: add known issue about diverted keys
  * docs: state that the Solaar GUI should run continously
  * cli: don't apply settings in solaar config
  * settings: move rawXY patch to new code for both sliding dpi and mouse gestures
  * ui: use device list in Active condition
  * ui: add description of rule components to rule editor
  * docs: add information on enhancement requests to add new devices
  * settings: ignore first movement for mouse gestures when reprog controls version is 5 or more
  * ui: add Active condition to rule editor
  * docs: document Active rule condition
  * rules: add rule condition to test whether a device is active
  * docs: update ERGO M575 Trackball 4096 description
  * docs: add Wireless Mobile Mouse MX Anywhere 2S 406A description
  * cli: terminate iteration over receiver devices when all have been found
  * rules: downgrade Set prolem messages from error to warning
  * ui: log informational messages and above to a temporary file
  * docs: add device information for ERGO M575 Trackball
  * ui: don't produce warnings when editing rules in rule editor
  * rules: save rules file even if there are no rules to save
  * docs: device documentation for MX Keys Keyboard and Wireless Mouse Pebble M350
  * device: get extended pairing information early and allow for unknown WPID
  * receiver: return null values if no pairing information available
  * receiver: use last_id as maximum device number not max_devices
  * cli: show more registers in solaar probe
  * docs: reflect change from json to yaml in capabilities documention
  * cli: show features versions in solaar show (#1709)
  * device: don't use field that may require communication with device in equality test
  * device: fix exception when removing device not in instance list
  * po: Use German word Gestentaste in translation
  * docs: update device documentation for MX Keys Mini and MX Master 3S
  * docs: update device directory documentation
  * docs: remove superceeded device documentation files
  * docs: update device documentation files
  * docs: new conventions for device documentation files
  * po: Added Serbian translation (#1687)
  * device: add desccriptor for G935 headset
  * device: add G502 Proteus Spectrum Optical Mouse
  * device: keep track of feature versions
  * po: update zh_TW translation (#1681)
  * rules: require gtk 3.0
  * rules: Fix circular import (#1673)
  * rules: find devices using method in Device
  * device: keep track of devices in list
  * po: update zh_CN translation
  * settings: convert old-style mouse gestures and dpi sliding settings to new style
  * docs: document changed Smart Shift and Mouse Gestures processing
  * settings: allow multiple keys for mouse gestures and dpi sliding
  * Fix release date in io.github.pwr_solaar.solaar.metainfo.xml
  * cli: explicitly save configuration at end of solaar config if no GUI running
  * configuration: defer configuration file writes for up to 5 seconds
  * device: use correct Solaar functions for unified and voltage battery functions
  * settings: defensive check for missing keys array in mouse gestures setting
  * device: compute approximate charge level for adc measurement feature
  * device: fix bugs in battery notification processing
  * ui: better presentation of battery information
  * device: add support for ADC MEASUREMENT battery feature
  * device: regularize and improve battery status gathering and reporting
  * doc: add information on how to find divertable key names in solaar show output
  * device: better warnings for feature call errors with reprogrammable key and gesture settings
  * ui: increase entry size for ChoiceControlBig
* Mon Jul  4 2022 asn@cryptomilk.org
- Update to version 1.1.4:
  * release 1.1.4
  * po: Update Croatian translation
  * po: Update Croatian translation
  * release 1.1.4rc2
  * settings: handle unusual values for persistent remappable action
  * settings: remove unused class variables
  * device: fix no-output values for persistent key mappings
  * doc: improve documentation on library needed for system tray integration
  * ui: remove blank lines from system tray popup
  * po: update Polish translation
* Mon May  9 2022 ecsos <ecsos@opensuse.org>
- Added python-dataclasses again. Without dataclasses solaar does
  not run under Leap.
  And python 3.6 is not deprecated in Leap 15.3 and 15.4.
  Suse support only python 3.6 as standard in Leap.
* Mon May  9 2022 Andreas Schneider <asn@cryptomilk.org>
- Drop python3-dataclasses which is only needed for Pyhton 3.6 and
  upstream doesn't support that python version anymore.
* Sat May  7 2022 ecsos <ecsos@opensuse.org>
- Fix needed dependencies.
- Run spec-cleaner.
* Mon May  2 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.3:
  * Update documentation files
  * Lower remove python 3.7 constructs and lower python dependency to 3.6
  * Fix bug in xtest mouse scrolling
  * Allow mouse gesture setting for non-mice, e.g., trackballs
  * Print message when there is another Solaar process running
  * Fix determination of whether to force read before writing boolean setting
  * Add recent diversion features to default list in rules UI
  * Add setting to divert hires scroll wheel
  * Don't use device kind to determine how to handle notifications
  * Update Polish, Russian, and zh_CN translations
  * Remove pggettext so as to not require Python 3.8
  * Remove Python 2 unicode support
  * Store keys in configuration file as int instead of str
  * Use yaml for configuration file instead of json.
  * Remove process-dependent rules from built-in rules.
  * Handle situation where GTK application cannot be set up in CLI.
  * Remove obsolete upower signals.
  * Appinfo/metadata fixes including using correct APP_ID.
  * Fix bugs in solaar config.
  * Add full set of mouse buttons in persistent remappable actions setting.
  * Improve rule behaviour under Wayland and when Xtest or X11 not available.
  * Fix up and document dependencies (evdev, Python, ...).
* Wed Mar 30 2022 Andreas Schneider <asn@cryptomilk.org>
- Add missing requirements
- Use python macros in spec file
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * Update documentation on supported devices and translations
  * Include evdev as a dependency
  * Try to use uinput for fake input if XTest extension not available
  * Add Nano receiver C542 for M190 mice
  * Broaden range of HID++ Bluetooth devices
  * Add setting to divert gestures
  * Rule editor can edit all rule components
  * Configuation via solaar config takes effect in Solaar UI if it is running
  * Add setting to disable Onboard Profiles and decouple from Polling Rate setting
  * Add setting for PERSISTENT_REMAPPABLE_ACTION, common keyboard and mouse cases only
  * Split Test rule condition into Test and TestBytes and support in rule editor
  * Fix bug in speed-change setting
  * Support Backlight3 feature
  * Ensure that settings are pushed in resume
  * Update German, Polish, and zh_CN translations
  * Determine device number for direct-connected devices from protocol
  * fix bug in add and delete button actions in rule editor
  * dispose of no-op notifications quickly
  * add rule condition for checking device settings
  * use local file for conversion from key names to keysyms
  * get keyboard group and use to get correct keycodes (X11 only)
  * improve how rules work under Wayland
  * add settings for M-Key LEDs and MR-Key LED
  * fix bug in unpacking M and MR key notification
  * add G815 keyboard and MX518 mouse
  * add new special keys for recent keyboards
  * track M and MR keys for use in rules
  * make sure that device is online when searching for devices in solaar show
  * don't check for device kind in dpi sliding setting
  * fix problem with devices that report 0 DPI
  * handle missing divert-setting in action RW for settings
  * add id property (unitId or serial) and don't use ? for unknown serial
  * fix contains for NamedInts and eliminate use of has_element
  * check for xtest and disable modifier checking if not available
  * improve determination of gesture information
  * add Set rules to rule GUI
  * add gesture params to Set rules
  * hide system tray when there are no devices to control
  * add G733 headset, G9 mouse, G502 Hero mouse
  * Use greyscale solaar icon in tray when using symbolic icons
  * Fix bugs in solaar config
  * Use classes for settings to hep with modularity
  * Accept '~' and Toggle for toggling boolean settings in cli and rules
  * handle errors when writing to devices
  * refactor config_panel.py to use classes for widgets
  * add rules action to set Solaar settings
  * decrease amount of logging at each debug level
  * don't stretch toggles in settings
  * use key structure for key remapping setting
  * optimize ReprogrammableKey implementation
  * keep track of settings that are absent from device
  * add G512 keyboard and G402 mouse
  * reformat descriptors.py
  * use feature numbers for reprogrammable key versions
  * don't use new_from_icon_set in menu as it is deprecated
* Wed Dec 29 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.1.1
  * Keep left pane in Solaar main window the same size
  * Fix crash when checking a process condition when X11 not
    running
  * Add version number to output of solaar show
  * Fix crash when pinging a device with unknown protocol
  * Display battery percentage estimates from battery voltage
  * Add minimal support for Logitech PRO X Wireless Gaming
    Headset
  * Push settings when device requests software reconfiguration
  * Fix read for key/button diversion setting
  * Add modalias information to Solaar metainfo
  * Don't do on-screen notifications when devices are powered on
  * Add setting to switch crown between smooth and ratchet
    scrolling
  * Add write_prefix_bytes argument to Boolean validator
  * Update Russian and Spanish translations
  * New shell script tools to help determine capabilities of
    receivers
  * Add special keys for MX Keys for Business and MX Keys Mini
  * Improve tray menu ordering
  * Add --tray-icon-size option to get around bugs in some tray
    implementations
* Sat Nov 27 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.0
  * https://github.com/pwr-Solaar/Solaar/blob/1.1.0/ChangeLog
- Add missing dependency to python3-PyYAML - bso#1193123
* Mon Oct 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.7
  * https://github.com/pwr-Solaar/Solaar/blob/1.0.7/ChangeLog
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Update sliding DPI to look for suitable keys
  * Add mouse gestures that can trigger rules
  * Complain if receivers do not support connection notification
  * In polling rate setting, only modify onboard profiles when actually writing polling rate
  * Add ability to ignore settings.
  * Use symbols for receiver sub-registers
  * Add support for wired G700
  * Do not set attention icon
  * Replace deprecated GTK stock menu icons
  * Better handling of icons in tray and tray menus
  * Receiver c52e does not unpair
  * Match active WM_CLASS as well as active process name in rules
  * Correctly set icon theme value when regular battery icons are not available
  * Handle exception when device is not available when device is being added
  * Perform initial activation of devices in listener threads
  * Keep track of serial numbers in the configuration file
  * Don't update settings for non-active devices
  * Set the current host name if not stored on the device
  * Add setting for SMART SHIFT ENHANCED feature
  * Don't unnecessarily use long messages for HID++ 1.0 commands
  * Correctly select choices in solaar config and use 1-origin addressing
  * Add quirk for G915 TKL keyboard because its host mode inteferes with its Fn keys
  * Show command outputs both saved and on-device settings
  * Update documentation
  * Fix bug in hidconsole
  * Update French translation
* Wed Jun  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%doc files. README.md is a symlink to
  'docs/index.md'. Let's use this file directly.
* Sat Feb 27 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.5
  * Update documentation on devices forgetting settings.
  * Improve help messages
  * Fix bug in finding receiver to pair
  * Solaar config command can set keyed settings.
* Thu Oct 22 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.4
  * Support USB and BT connected devices that are not in descriptors.py
  * Use FRIENDLY NAME for codename if needed and available.
  * Extract manufacturer and product ID from Udev HID information.
  * Add Bluetooth and USB product IDs to device descriptors records.
  * Support Bluetooth-connected devices.
  * Add model ID and unit ID to device identification.
  * Support changing DPI by pressing DPI Switch button and sliding horizontally
  * Add device-specific notification handlers.
  * Add MX Vertical USB information.
  * Udev rule adds seat permissions for all Logitech devices.
  * Support USB-connected devices in GUI.
  * Make probe and config work for USB-connected devices.
  * Improve strings and display for settings.
  * Correctly handle non-unifying connection notifications.
  * Update GUI strings for several settings.
  * Better support for EX100 and devices that connect to it.
  * Partial support for feature GESTURE_2.
  * Simplify interface for settings.
  * Use DJ connection notifications to set device active status
  * Udev rule sets seat write permissions for hidraw nodes for device as well as receivers.
  * Handle USB devices that use HID++ protocol in CLI.
  * Use device hidraw nodes where possible.
  * Handle receivers with serial numbers that don't provide number of pairings.
  * Ignore exceptions when setting locale.
  * Correctly discover settings that share a name.
  * Don't show pop-up notifications at startup.
  * Keep battery voltage updated in GUI.
  * Add Portugese translation.
  * Update several translations.
  * Add Lightspeed receivers c545 and c541.
  * Reimplement REPROG_CONTROLS data structure.
* Mon Aug  3 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.3
  * Remove deprecated solaar-cli application.
  * Don't install udev or autostart files from python (or pip).
  * Solaar needs Python 3.6+ and probably needs kernel 5.2+
  * Handle exceptions on dynamic settings when device is not connected.
  * Fix inifinite loop on some low-level write errors
  * Add support for EX100 keyboard/mouse and receiver (046d:c517)
  * Add two settings for THUMB_WHEEL feature - inversion and reporting via HID++
  * Update German translation
  * Use REPORT RATE feature when available to determine polling rate.
  * Improve config command speed when not printing all settings
  * Improve config command handling and checking of arguments
  * Add setting for CHANGE_HOST feature
  * Add argument to settings for values that are not to persist
  * Add argument to settings to not wait for reply when writing a value to device
  * Add argument to not wait for reply from request to device
  * Add settings for MULTIPLATFORM and DUALPLATFORM features
  * Remove Logitech documents from documentation directory
  * Change config command to not read all settings when only printing or showing one
  * Display hosts info in 'solaar show' if device supports it
  * Remove non-working smooth-scrool from M510 v1
  * Add yapf and flake8 code style checks
  * Fix feature k375s Fn inversion
  * Update controls (keys and buttons) and tasks (actions)
  * Improved way to specify feature settings.
  * Don't abort on device notifications with unexpected device numbers, just warn.
  * Keep track of non-features so as not to ask device multiple times.
  * Implement KEYBOARD DISABLE KEYS feature.
  * Don't create notifications for DJ device activity reports.
  * Update a few special keys and actions.
  * Add keyed choice settings in configuration panel.
  * Support remappable keys from reprogrammable keys v4 feature.
  * Add setting class for keyed choice.
  * Only check for features once per device.
  * Use settings interface to show feature values in solaar show if no special code for feature.
  * Remove maximum window size.
  * Process battery voltage notifications.
  * Display battery voltage information in main window if regular battery information not available.
  * Show next battery level where available.
  * Update list of implemented features and provide information on how to implement features.
  * Add c53d as a Lightspeed receiver.
* Sat May 23 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.2
- Removed 0001-Fix-reading-and-storing-DPI-in-config-settings.patch
- Removed 0001-data-fix-icon-theme-for-battery-level.patch
- Removed 0005-notifications-fix-battery-status-notification-parsin.patch
* Thu Oct  3 2019 Andreas Schneider <asn@cryptomilk.org>
- Add missing Requries for python3-gobject-Gdk
* Wed Sep 18 2019 Andreas Schneider <asn@cryptomilk.org>
- Apply udev rules to existing devices
* Tue Sep 17 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix icon theme for battery level
  + Added 0001-data-fix-icon-theme-for-battery-level.patch
- Fix battery status notifaction parsing
  + Added 0005-notifications-fix-battery-status-notification-parsin.patch
* Thu Aug 22 2019 Andreas Schneider <asn@cryptomilk.org>
- Add a conflict with solaar-cli to solar-udev
* Thu Aug  1 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix reading and storing DPI settings
  + Added 0001-Fix-reading-and-storing-DPI-in-config-settings.patch
* Sat Jul 27 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.1:
  * Updated the repo url.
  * Fixed typo which was crashing the application.
  * Improved the HID write routine which was causing issues on some devices.
  * Fix non-unifying receivers in Linux 5.2.
  * Add new Lightspeed receiver (used in the G305)
- Updates from version 1.0.0:
  * First major release after 6 years
  * Support for a lot of new mice and keyboards
* Tue Jun 10 2014 dmitry_r@opensuse.org
- Disable autostart options in setup script
* Wed May  7 2014 dmitry_r@opensuse.org
- Split CLI to separate package
- Add runtime requirements
- Use original udev rules
* Tue Aug  6 2013 malcolmlewis@opensuse.org
- Updated to version 0.9.2:
  + Added support for hand detection on the K800.
  + Added support for V550 and V450 Nano.
  + Fixed side-scrolling wit the M705 Marathon.
  + Fixed identification of the T650 Touchpad.
  + Added internationalization support and romanian translation.
  + Polish translation courtesy of Adrian Piotrowicz.
- Updates from version 0.9.1:
  + When devices report a battery alert, only show the alert once.
  + Make sure devices in the window tree are sorted by registration
    index.
  + Added an autostart .desktop file.
  + Replaced single-instance code with GtkApplication.
  + Fixed indentification of the M505 mouse.
  + Fixed an occasional windowing layout bug with the C52F Nano
    Receiver.
- Updates from version 0.9.0:
  + New single-window UI.
  + Performance MX leds show the current battery charge.
  + Support the VX Nano mouse.
  + Faster and more accurate detection of devices.
  + If upower is accessible through DBus, handle suspend/resume.
  + Replaced Solaar icons with SVGs.
  + Running solaar-cli in parallel with solaar is now less likely
    to cause issues.
  + Bugfixes to saving and applying device settings.
  + Properly handle ^C when running in console.
* Thu Jun 27 2013 malcolmlewis@opensuse.org
- Initial build.
- Add 99-logitech-unifying-receiver.rules: openSUSE specific udev
  rule.
- Add solaar-fix-desktop-categories.patch: Fix desktop categories
  as per openSUSE desktop file specification.
